# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SecretBackendCrlConfigArgs', 'SecretBackendCrlConfig']

@pulumi.input_type
class SecretBackendCrlConfigArgs:
    def __init__(__self__, *,
                 backend: pulumi.Input[str],
                 auto_rebuild: Optional[pulumi.Input[bool]] = None,
                 auto_rebuild_grace_period: Optional[pulumi.Input[str]] = None,
                 cross_cluster_revocation: Optional[pulumi.Input[bool]] = None,
                 delta_rebuild_interval: Optional[pulumi.Input[str]] = None,
                 disable: Optional[pulumi.Input[bool]] = None,
                 enable_delta: Optional[pulumi.Input[bool]] = None,
                 expiry: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 ocsp_disable: Optional[pulumi.Input[bool]] = None,
                 ocsp_expiry: Optional[pulumi.Input[str]] = None,
                 unified_crl: Optional[pulumi.Input[bool]] = None,
                 unified_crl_on_existing_paths: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a SecretBackendCrlConfig resource.
        :param pulumi.Input[str] backend: The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        :param pulumi.Input[bool] auto_rebuild: Enables periodic rebuilding of the CRL upon expiry. **Vault 1.12+**
        :param pulumi.Input[str] auto_rebuild_grace_period: Grace period before CRL expiry to attempt rebuild of CRL. **Vault 1.12+**
        :param pulumi.Input[bool] cross_cluster_revocation: Enable cross-cluster revocation request queues. **Vault 1.13+**
        :param pulumi.Input[str] delta_rebuild_interval: Interval to check for new revocations on, to regenerate the delta CRL.
        :param pulumi.Input[bool] disable: Disables or enables CRL building.
        :param pulumi.Input[bool] enable_delta: Enables building of delta CRLs with up-to-date revocation information, 
               augmenting the last complete CRL.  **Vault 1.12+**
        :param pulumi.Input[str] expiry: Specifies the time until expiration.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] ocsp_disable: Disables the OCSP responder in Vault. **Vault 1.12+**
        :param pulumi.Input[str] ocsp_expiry: The amount of time an OCSP response can be cached for, useful for OCSP stapling 
               refresh durations. **Vault 1.12+**
        :param pulumi.Input[bool] unified_crl: Enables unified CRL and OCSP building. **Vault 1.13+**
        :param pulumi.Input[bool] unified_crl_on_existing_paths: Enables serving the unified CRL and OCSP on the existing, previously
               cluster-local paths. **Vault 1.13+**
        """
        pulumi.set(__self__, "backend", backend)
        if auto_rebuild is not None:
            pulumi.set(__self__, "auto_rebuild", auto_rebuild)
        if auto_rebuild_grace_period is not None:
            pulumi.set(__self__, "auto_rebuild_grace_period", auto_rebuild_grace_period)
        if cross_cluster_revocation is not None:
            pulumi.set(__self__, "cross_cluster_revocation", cross_cluster_revocation)
        if delta_rebuild_interval is not None:
            pulumi.set(__self__, "delta_rebuild_interval", delta_rebuild_interval)
        if disable is not None:
            pulumi.set(__self__, "disable", disable)
        if enable_delta is not None:
            pulumi.set(__self__, "enable_delta", enable_delta)
        if expiry is not None:
            pulumi.set(__self__, "expiry", expiry)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if ocsp_disable is not None:
            pulumi.set(__self__, "ocsp_disable", ocsp_disable)
        if ocsp_expiry is not None:
            pulumi.set(__self__, "ocsp_expiry", ocsp_expiry)
        if unified_crl is not None:
            pulumi.set(__self__, "unified_crl", unified_crl)
        if unified_crl_on_existing_paths is not None:
            pulumi.set(__self__, "unified_crl_on_existing_paths", unified_crl_on_existing_paths)

    @property
    @pulumi.getter
    def backend(self) -> pulumi.Input[str]:
        """
        The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: pulumi.Input[str]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter(name="autoRebuild")
    def auto_rebuild(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables periodic rebuilding of the CRL upon expiry. **Vault 1.12+**
        """
        return pulumi.get(self, "auto_rebuild")

    @auto_rebuild.setter
    def auto_rebuild(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_rebuild", value)

    @property
    @pulumi.getter(name="autoRebuildGracePeriod")
    def auto_rebuild_grace_period(self) -> Optional[pulumi.Input[str]]:
        """
        Grace period before CRL expiry to attempt rebuild of CRL. **Vault 1.12+**
        """
        return pulumi.get(self, "auto_rebuild_grace_period")

    @auto_rebuild_grace_period.setter
    def auto_rebuild_grace_period(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_rebuild_grace_period", value)

    @property
    @pulumi.getter(name="crossClusterRevocation")
    def cross_cluster_revocation(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable cross-cluster revocation request queues. **Vault 1.13+**
        """
        return pulumi.get(self, "cross_cluster_revocation")

    @cross_cluster_revocation.setter
    def cross_cluster_revocation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cross_cluster_revocation", value)

    @property
    @pulumi.getter(name="deltaRebuildInterval")
    def delta_rebuild_interval(self) -> Optional[pulumi.Input[str]]:
        """
        Interval to check for new revocations on, to regenerate the delta CRL.
        """
        return pulumi.get(self, "delta_rebuild_interval")

    @delta_rebuild_interval.setter
    def delta_rebuild_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "delta_rebuild_interval", value)

    @property
    @pulumi.getter
    def disable(self) -> Optional[pulumi.Input[bool]]:
        """
        Disables or enables CRL building.
        """
        return pulumi.get(self, "disable")

    @disable.setter
    def disable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disable", value)

    @property
    @pulumi.getter(name="enableDelta")
    def enable_delta(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables building of delta CRLs with up-to-date revocation information, 
        augmenting the last complete CRL.  **Vault 1.12+**
        """
        return pulumi.get(self, "enable_delta")

    @enable_delta.setter
    def enable_delta(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_delta", value)

    @property
    @pulumi.getter
    def expiry(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the time until expiration.
        """
        return pulumi.get(self, "expiry")

    @expiry.setter
    def expiry(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expiry", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="ocspDisable")
    def ocsp_disable(self) -> Optional[pulumi.Input[bool]]:
        """
        Disables the OCSP responder in Vault. **Vault 1.12+**
        """
        return pulumi.get(self, "ocsp_disable")

    @ocsp_disable.setter
    def ocsp_disable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ocsp_disable", value)

    @property
    @pulumi.getter(name="ocspExpiry")
    def ocsp_expiry(self) -> Optional[pulumi.Input[str]]:
        """
        The amount of time an OCSP response can be cached for, useful for OCSP stapling 
        refresh durations. **Vault 1.12+**
        """
        return pulumi.get(self, "ocsp_expiry")

    @ocsp_expiry.setter
    def ocsp_expiry(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ocsp_expiry", value)

    @property
    @pulumi.getter(name="unifiedCrl")
    def unified_crl(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables unified CRL and OCSP building. **Vault 1.13+**
        """
        return pulumi.get(self, "unified_crl")

    @unified_crl.setter
    def unified_crl(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "unified_crl", value)

    @property
    @pulumi.getter(name="unifiedCrlOnExistingPaths")
    def unified_crl_on_existing_paths(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables serving the unified CRL and OCSP on the existing, previously
        cluster-local paths. **Vault 1.13+**
        """
        return pulumi.get(self, "unified_crl_on_existing_paths")

    @unified_crl_on_existing_paths.setter
    def unified_crl_on_existing_paths(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "unified_crl_on_existing_paths", value)


@pulumi.input_type
class _SecretBackendCrlConfigState:
    def __init__(__self__, *,
                 auto_rebuild: Optional[pulumi.Input[bool]] = None,
                 auto_rebuild_grace_period: Optional[pulumi.Input[str]] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 cross_cluster_revocation: Optional[pulumi.Input[bool]] = None,
                 delta_rebuild_interval: Optional[pulumi.Input[str]] = None,
                 disable: Optional[pulumi.Input[bool]] = None,
                 enable_delta: Optional[pulumi.Input[bool]] = None,
                 expiry: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 ocsp_disable: Optional[pulumi.Input[bool]] = None,
                 ocsp_expiry: Optional[pulumi.Input[str]] = None,
                 unified_crl: Optional[pulumi.Input[bool]] = None,
                 unified_crl_on_existing_paths: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering SecretBackendCrlConfig resources.
        :param pulumi.Input[bool] auto_rebuild: Enables periodic rebuilding of the CRL upon expiry. **Vault 1.12+**
        :param pulumi.Input[str] auto_rebuild_grace_period: Grace period before CRL expiry to attempt rebuild of CRL. **Vault 1.12+**
        :param pulumi.Input[str] backend: The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        :param pulumi.Input[bool] cross_cluster_revocation: Enable cross-cluster revocation request queues. **Vault 1.13+**
        :param pulumi.Input[str] delta_rebuild_interval: Interval to check for new revocations on, to regenerate the delta CRL.
        :param pulumi.Input[bool] disable: Disables or enables CRL building.
        :param pulumi.Input[bool] enable_delta: Enables building of delta CRLs with up-to-date revocation information, 
               augmenting the last complete CRL.  **Vault 1.12+**
        :param pulumi.Input[str] expiry: Specifies the time until expiration.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] ocsp_disable: Disables the OCSP responder in Vault. **Vault 1.12+**
        :param pulumi.Input[str] ocsp_expiry: The amount of time an OCSP response can be cached for, useful for OCSP stapling 
               refresh durations. **Vault 1.12+**
        :param pulumi.Input[bool] unified_crl: Enables unified CRL and OCSP building. **Vault 1.13+**
        :param pulumi.Input[bool] unified_crl_on_existing_paths: Enables serving the unified CRL and OCSP on the existing, previously
               cluster-local paths. **Vault 1.13+**
        """
        if auto_rebuild is not None:
            pulumi.set(__self__, "auto_rebuild", auto_rebuild)
        if auto_rebuild_grace_period is not None:
            pulumi.set(__self__, "auto_rebuild_grace_period", auto_rebuild_grace_period)
        if backend is not None:
            pulumi.set(__self__, "backend", backend)
        if cross_cluster_revocation is not None:
            pulumi.set(__self__, "cross_cluster_revocation", cross_cluster_revocation)
        if delta_rebuild_interval is not None:
            pulumi.set(__self__, "delta_rebuild_interval", delta_rebuild_interval)
        if disable is not None:
            pulumi.set(__self__, "disable", disable)
        if enable_delta is not None:
            pulumi.set(__self__, "enable_delta", enable_delta)
        if expiry is not None:
            pulumi.set(__self__, "expiry", expiry)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if ocsp_disable is not None:
            pulumi.set(__self__, "ocsp_disable", ocsp_disable)
        if ocsp_expiry is not None:
            pulumi.set(__self__, "ocsp_expiry", ocsp_expiry)
        if unified_crl is not None:
            pulumi.set(__self__, "unified_crl", unified_crl)
        if unified_crl_on_existing_paths is not None:
            pulumi.set(__self__, "unified_crl_on_existing_paths", unified_crl_on_existing_paths)

    @property
    @pulumi.getter(name="autoRebuild")
    def auto_rebuild(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables periodic rebuilding of the CRL upon expiry. **Vault 1.12+**
        """
        return pulumi.get(self, "auto_rebuild")

    @auto_rebuild.setter
    def auto_rebuild(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_rebuild", value)

    @property
    @pulumi.getter(name="autoRebuildGracePeriod")
    def auto_rebuild_grace_period(self) -> Optional[pulumi.Input[str]]:
        """
        Grace period before CRL expiry to attempt rebuild of CRL. **Vault 1.12+**
        """
        return pulumi.get(self, "auto_rebuild_grace_period")

    @auto_rebuild_grace_period.setter
    def auto_rebuild_grace_period(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_rebuild_grace_period", value)

    @property
    @pulumi.getter
    def backend(self) -> Optional[pulumi.Input[str]]:
        """
        The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @backend.setter
    def backend(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "backend", value)

    @property
    @pulumi.getter(name="crossClusterRevocation")
    def cross_cluster_revocation(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable cross-cluster revocation request queues. **Vault 1.13+**
        """
        return pulumi.get(self, "cross_cluster_revocation")

    @cross_cluster_revocation.setter
    def cross_cluster_revocation(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cross_cluster_revocation", value)

    @property
    @pulumi.getter(name="deltaRebuildInterval")
    def delta_rebuild_interval(self) -> Optional[pulumi.Input[str]]:
        """
        Interval to check for new revocations on, to regenerate the delta CRL.
        """
        return pulumi.get(self, "delta_rebuild_interval")

    @delta_rebuild_interval.setter
    def delta_rebuild_interval(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "delta_rebuild_interval", value)

    @property
    @pulumi.getter
    def disable(self) -> Optional[pulumi.Input[bool]]:
        """
        Disables or enables CRL building.
        """
        return pulumi.get(self, "disable")

    @disable.setter
    def disable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disable", value)

    @property
    @pulumi.getter(name="enableDelta")
    def enable_delta(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables building of delta CRLs with up-to-date revocation information, 
        augmenting the last complete CRL.  **Vault 1.12+**
        """
        return pulumi.get(self, "enable_delta")

    @enable_delta.setter
    def enable_delta(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_delta", value)

    @property
    @pulumi.getter
    def expiry(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the time until expiration.
        """
        return pulumi.get(self, "expiry")

    @expiry.setter
    def expiry(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expiry", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="ocspDisable")
    def ocsp_disable(self) -> Optional[pulumi.Input[bool]]:
        """
        Disables the OCSP responder in Vault. **Vault 1.12+**
        """
        return pulumi.get(self, "ocsp_disable")

    @ocsp_disable.setter
    def ocsp_disable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ocsp_disable", value)

    @property
    @pulumi.getter(name="ocspExpiry")
    def ocsp_expiry(self) -> Optional[pulumi.Input[str]]:
        """
        The amount of time an OCSP response can be cached for, useful for OCSP stapling 
        refresh durations. **Vault 1.12+**
        """
        return pulumi.get(self, "ocsp_expiry")

    @ocsp_expiry.setter
    def ocsp_expiry(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ocsp_expiry", value)

    @property
    @pulumi.getter(name="unifiedCrl")
    def unified_crl(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables unified CRL and OCSP building. **Vault 1.13+**
        """
        return pulumi.get(self, "unified_crl")

    @unified_crl.setter
    def unified_crl(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "unified_crl", value)

    @property
    @pulumi.getter(name="unifiedCrlOnExistingPaths")
    def unified_crl_on_existing_paths(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables serving the unified CRL and OCSP on the existing, previously
        cluster-local paths. **Vault 1.13+**
        """
        return pulumi.get(self, "unified_crl_on_existing_paths")

    @unified_crl_on_existing_paths.setter
    def unified_crl_on_existing_paths(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "unified_crl_on_existing_paths", value)


class SecretBackendCrlConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_rebuild: Optional[pulumi.Input[bool]] = None,
                 auto_rebuild_grace_period: Optional[pulumi.Input[str]] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 cross_cluster_revocation: Optional[pulumi.Input[bool]] = None,
                 delta_rebuild_interval: Optional[pulumi.Input[str]] = None,
                 disable: Optional[pulumi.Input[bool]] = None,
                 enable_delta: Optional[pulumi.Input[bool]] = None,
                 expiry: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 ocsp_disable: Optional[pulumi.Input[bool]] = None,
                 ocsp_expiry: Optional[pulumi.Input[str]] = None,
                 unified_crl: Optional[pulumi.Input[bool]] = None,
                 unified_crl_on_existing_paths: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Allows setting the duration for which the generated CRL should be marked valid. If the CRL is disabled, it will return a signed but zero-length CRL for any request. If enabled, it will re-build the CRL.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        pki = vault.Mount("pki",
            path="%s",
            type="pki",
            default_lease_ttl_seconds=3600,
            max_lease_ttl_seconds=86400)
        crl_config = vault.pki_secret.SecretBackendCrlConfig("crlConfig",
            backend=pki.path,
            expiry="72h",
            disable=False)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_rebuild: Enables periodic rebuilding of the CRL upon expiry. **Vault 1.12+**
        :param pulumi.Input[str] auto_rebuild_grace_period: Grace period before CRL expiry to attempt rebuild of CRL. **Vault 1.12+**
        :param pulumi.Input[str] backend: The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        :param pulumi.Input[bool] cross_cluster_revocation: Enable cross-cluster revocation request queues. **Vault 1.13+**
        :param pulumi.Input[str] delta_rebuild_interval: Interval to check for new revocations on, to regenerate the delta CRL.
        :param pulumi.Input[bool] disable: Disables or enables CRL building.
        :param pulumi.Input[bool] enable_delta: Enables building of delta CRLs with up-to-date revocation information, 
               augmenting the last complete CRL.  **Vault 1.12+**
        :param pulumi.Input[str] expiry: Specifies the time until expiration.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] ocsp_disable: Disables the OCSP responder in Vault. **Vault 1.12+**
        :param pulumi.Input[str] ocsp_expiry: The amount of time an OCSP response can be cached for, useful for OCSP stapling 
               refresh durations. **Vault 1.12+**
        :param pulumi.Input[bool] unified_crl: Enables unified CRL and OCSP building. **Vault 1.13+**
        :param pulumi.Input[bool] unified_crl_on_existing_paths: Enables serving the unified CRL and OCSP on the existing, previously
               cluster-local paths. **Vault 1.13+**
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecretBackendCrlConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Allows setting the duration for which the generated CRL should be marked valid. If the CRL is disabled, it will return a signed but zero-length CRL for any request. If enabled, it will re-build the CRL.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        pki = vault.Mount("pki",
            path="%s",
            type="pki",
            default_lease_ttl_seconds=3600,
            max_lease_ttl_seconds=86400)
        crl_config = vault.pki_secret.SecretBackendCrlConfig("crlConfig",
            backend=pki.path,
            expiry="72h",
            disable=False)
        ```

        :param str resource_name: The name of the resource.
        :param SecretBackendCrlConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecretBackendCrlConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_rebuild: Optional[pulumi.Input[bool]] = None,
                 auto_rebuild_grace_period: Optional[pulumi.Input[str]] = None,
                 backend: Optional[pulumi.Input[str]] = None,
                 cross_cluster_revocation: Optional[pulumi.Input[bool]] = None,
                 delta_rebuild_interval: Optional[pulumi.Input[str]] = None,
                 disable: Optional[pulumi.Input[bool]] = None,
                 enable_delta: Optional[pulumi.Input[bool]] = None,
                 expiry: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 ocsp_disable: Optional[pulumi.Input[bool]] = None,
                 ocsp_expiry: Optional[pulumi.Input[str]] = None,
                 unified_crl: Optional[pulumi.Input[bool]] = None,
                 unified_crl_on_existing_paths: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecretBackendCrlConfigArgs.__new__(SecretBackendCrlConfigArgs)

            __props__.__dict__["auto_rebuild"] = auto_rebuild
            __props__.__dict__["auto_rebuild_grace_period"] = auto_rebuild_grace_period
            if backend is None and not opts.urn:
                raise TypeError("Missing required property 'backend'")
            __props__.__dict__["backend"] = backend
            __props__.__dict__["cross_cluster_revocation"] = cross_cluster_revocation
            __props__.__dict__["delta_rebuild_interval"] = delta_rebuild_interval
            __props__.__dict__["disable"] = disable
            __props__.__dict__["enable_delta"] = enable_delta
            __props__.__dict__["expiry"] = expiry
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["ocsp_disable"] = ocsp_disable
            __props__.__dict__["ocsp_expiry"] = ocsp_expiry
            __props__.__dict__["unified_crl"] = unified_crl
            __props__.__dict__["unified_crl_on_existing_paths"] = unified_crl_on_existing_paths
        super(SecretBackendCrlConfig, __self__).__init__(
            'vault:pkiSecret/secretBackendCrlConfig:SecretBackendCrlConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_rebuild: Optional[pulumi.Input[bool]] = None,
            auto_rebuild_grace_period: Optional[pulumi.Input[str]] = None,
            backend: Optional[pulumi.Input[str]] = None,
            cross_cluster_revocation: Optional[pulumi.Input[bool]] = None,
            delta_rebuild_interval: Optional[pulumi.Input[str]] = None,
            disable: Optional[pulumi.Input[bool]] = None,
            enable_delta: Optional[pulumi.Input[bool]] = None,
            expiry: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            ocsp_disable: Optional[pulumi.Input[bool]] = None,
            ocsp_expiry: Optional[pulumi.Input[str]] = None,
            unified_crl: Optional[pulumi.Input[bool]] = None,
            unified_crl_on_existing_paths: Optional[pulumi.Input[bool]] = None) -> 'SecretBackendCrlConfig':
        """
        Get an existing SecretBackendCrlConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_rebuild: Enables periodic rebuilding of the CRL upon expiry. **Vault 1.12+**
        :param pulumi.Input[str] auto_rebuild_grace_period: Grace period before CRL expiry to attempt rebuild of CRL. **Vault 1.12+**
        :param pulumi.Input[str] backend: The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        :param pulumi.Input[bool] cross_cluster_revocation: Enable cross-cluster revocation request queues. **Vault 1.13+**
        :param pulumi.Input[str] delta_rebuild_interval: Interval to check for new revocations on, to regenerate the delta CRL.
        :param pulumi.Input[bool] disable: Disables or enables CRL building.
        :param pulumi.Input[bool] enable_delta: Enables building of delta CRLs with up-to-date revocation information, 
               augmenting the last complete CRL.  **Vault 1.12+**
        :param pulumi.Input[str] expiry: Specifies the time until expiration.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[bool] ocsp_disable: Disables the OCSP responder in Vault. **Vault 1.12+**
        :param pulumi.Input[str] ocsp_expiry: The amount of time an OCSP response can be cached for, useful for OCSP stapling 
               refresh durations. **Vault 1.12+**
        :param pulumi.Input[bool] unified_crl: Enables unified CRL and OCSP building. **Vault 1.13+**
        :param pulumi.Input[bool] unified_crl_on_existing_paths: Enables serving the unified CRL and OCSP on the existing, previously
               cluster-local paths. **Vault 1.13+**
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecretBackendCrlConfigState.__new__(_SecretBackendCrlConfigState)

        __props__.__dict__["auto_rebuild"] = auto_rebuild
        __props__.__dict__["auto_rebuild_grace_period"] = auto_rebuild_grace_period
        __props__.__dict__["backend"] = backend
        __props__.__dict__["cross_cluster_revocation"] = cross_cluster_revocation
        __props__.__dict__["delta_rebuild_interval"] = delta_rebuild_interval
        __props__.__dict__["disable"] = disable
        __props__.__dict__["enable_delta"] = enable_delta
        __props__.__dict__["expiry"] = expiry
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["ocsp_disable"] = ocsp_disable
        __props__.__dict__["ocsp_expiry"] = ocsp_expiry
        __props__.__dict__["unified_crl"] = unified_crl
        __props__.__dict__["unified_crl_on_existing_paths"] = unified_crl_on_existing_paths
        return SecretBackendCrlConfig(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoRebuild")
    def auto_rebuild(self) -> pulumi.Output[Optional[bool]]:
        """
        Enables periodic rebuilding of the CRL upon expiry. **Vault 1.12+**
        """
        return pulumi.get(self, "auto_rebuild")

    @property
    @pulumi.getter(name="autoRebuildGracePeriod")
    def auto_rebuild_grace_period(self) -> pulumi.Output[str]:
        """
        Grace period before CRL expiry to attempt rebuild of CRL. **Vault 1.12+**
        """
        return pulumi.get(self, "auto_rebuild_grace_period")

    @property
    @pulumi.getter
    def backend(self) -> pulumi.Output[str]:
        """
        The path the PKI secret backend is mounted at, with no leading or trailing `/`s.
        """
        return pulumi.get(self, "backend")

    @property
    @pulumi.getter(name="crossClusterRevocation")
    def cross_cluster_revocation(self) -> pulumi.Output[bool]:
        """
        Enable cross-cluster revocation request queues. **Vault 1.13+**
        """
        return pulumi.get(self, "cross_cluster_revocation")

    @property
    @pulumi.getter(name="deltaRebuildInterval")
    def delta_rebuild_interval(self) -> pulumi.Output[str]:
        """
        Interval to check for new revocations on, to regenerate the delta CRL.
        """
        return pulumi.get(self, "delta_rebuild_interval")

    @property
    @pulumi.getter
    def disable(self) -> pulumi.Output[Optional[bool]]:
        """
        Disables or enables CRL building.
        """
        return pulumi.get(self, "disable")

    @property
    @pulumi.getter(name="enableDelta")
    def enable_delta(self) -> pulumi.Output[Optional[bool]]:
        """
        Enables building of delta CRLs with up-to-date revocation information, 
        augmenting the last complete CRL.  **Vault 1.12+**
        """
        return pulumi.get(self, "enable_delta")

    @property
    @pulumi.getter
    def expiry(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the time until expiration.
        """
        return pulumi.get(self, "expiry")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="ocspDisable")
    def ocsp_disable(self) -> pulumi.Output[Optional[bool]]:
        """
        Disables the OCSP responder in Vault. **Vault 1.12+**
        """
        return pulumi.get(self, "ocsp_disable")

    @property
    @pulumi.getter(name="ocspExpiry")
    def ocsp_expiry(self) -> pulumi.Output[str]:
        """
        The amount of time an OCSP response can be cached for, useful for OCSP stapling 
        refresh durations. **Vault 1.12+**
        """
        return pulumi.get(self, "ocsp_expiry")

    @property
    @pulumi.getter(name="unifiedCrl")
    def unified_crl(self) -> pulumi.Output[bool]:
        """
        Enables unified CRL and OCSP building. **Vault 1.13+**
        """
        return pulumi.get(self, "unified_crl")

    @property
    @pulumi.getter(name="unifiedCrlOnExistingPaths")
    def unified_crl_on_existing_paths(self) -> pulumi.Output[bool]:
        """
        Enables serving the unified CRL and OCSP on the existing, previously
        cluster-local paths. **Vault 1.13+**
        """
        return pulumi.get(self, "unified_crl_on_existing_paths")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['MfaPingidArgs', 'MfaPingid']

@pulumi.input_type
class MfaPingidArgs:
    def __init__(__self__, *,
                 mount_accessor: pulumi.Input[str],
                 settings_file_base64: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 username_format: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a MfaPingid resource.
        :param pulumi.Input[str] mount_accessor: `(string: <required>)` - The mount to tie this method to for use in automatic mappings. 
               The mapping will use the Name field of Aliases associated with this mount as the username in the mapping.
        :param pulumi.Input[str] settings_file_base64: `(string: <required>)` - A base64-encoded third-party settings file retrieved
               from PingID's configuration page.
        :param pulumi.Input[str] name: `(string: <required>)` – Name of the MFA method.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] username_format: `(string)` - A format string for mapping Identity names to MFA method names. 
               Values to substitute should be placed in `{{}}`. For example, `"{{alias.name}}@example.com"`.
               If blank, the Alias's Name field will be used as-is. Currently-supported mappings:
               - alias.name: The name returned by the mount configured via the `mount_accessor` parameter
               - entity.name: The name configured for the Entity
               - alias.metadata.`<key>`: The value of the Alias's metadata parameter
               - entity.metadata.`<key>`: The value of the Entity's metadata parameter
        """
        pulumi.set(__self__, "mount_accessor", mount_accessor)
        pulumi.set(__self__, "settings_file_base64", settings_file_base64)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if username_format is not None:
            pulumi.set(__self__, "username_format", username_format)

    @property
    @pulumi.getter(name="mountAccessor")
    def mount_accessor(self) -> pulumi.Input[str]:
        """
        `(string: <required>)` - The mount to tie this method to for use in automatic mappings. 
        The mapping will use the Name field of Aliases associated with this mount as the username in the mapping.
        """
        return pulumi.get(self, "mount_accessor")

    @mount_accessor.setter
    def mount_accessor(self, value: pulumi.Input[str]):
        pulumi.set(self, "mount_accessor", value)

    @property
    @pulumi.getter(name="settingsFileBase64")
    def settings_file_base64(self) -> pulumi.Input[str]:
        """
        `(string: <required>)` - A base64-encoded third-party settings file retrieved
        from PingID's configuration page.
        """
        return pulumi.get(self, "settings_file_base64")

    @settings_file_base64.setter
    def settings_file_base64(self, value: pulumi.Input[str]):
        pulumi.set(self, "settings_file_base64", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        `(string: <required>)` – Name of the MFA method.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="usernameFormat")
    def username_format(self) -> Optional[pulumi.Input[str]]:
        """
        `(string)` - A format string for mapping Identity names to MFA method names. 
        Values to substitute should be placed in `{{}}`. For example, `"{{alias.name}}@example.com"`.
        If blank, the Alias's Name field will be used as-is. Currently-supported mappings:
        - alias.name: The name returned by the mount configured via the `mount_accessor` parameter
        - entity.name: The name configured for the Entity
        - alias.metadata.`<key>`: The value of the Alias's metadata parameter
        - entity.metadata.`<key>`: The value of the Entity's metadata parameter
        """
        return pulumi.get(self, "username_format")

    @username_format.setter
    def username_format(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username_format", value)


@pulumi.input_type
class _MfaPingidState:
    def __init__(__self__, *,
                 admin_url: Optional[pulumi.Input[str]] = None,
                 authenticator_url: Optional[pulumi.Input[str]] = None,
                 idp_url: Optional[pulumi.Input[str]] = None,
                 mount_accessor: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 namespace_id: Optional[pulumi.Input[str]] = None,
                 org_alias: Optional[pulumi.Input[str]] = None,
                 settings_file_base64: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 use_signature: Optional[pulumi.Input[bool]] = None,
                 username_format: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering MfaPingid resources.
        :param pulumi.Input[str] admin_url: `(string)` – Admin URL computed by Vault
        :param pulumi.Input[str] authenticator_url: `(string)` – Authenticator URL computed by Vault
        :param pulumi.Input[str] idp_url: `(string)` – IDP URL computed by Vault
        :param pulumi.Input[str] mount_accessor: `(string: <required>)` - The mount to tie this method to for use in automatic mappings. 
               The mapping will use the Name field of Aliases associated with this mount as the username in the mapping.
        :param pulumi.Input[str] name: `(string: <required>)` – Name of the MFA method.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] namespace_id: `(string)` – Namespace ID computed by Vault
        :param pulumi.Input[str] org_alias: `(string)` – Org Alias computed by Vault
        :param pulumi.Input[str] settings_file_base64: `(string: <required>)` - A base64-encoded third-party settings file retrieved
               from PingID's configuration page.
        :param pulumi.Input[str] type: `(string)` – Type of configuration computed by Vault
        :param pulumi.Input[bool] use_signature: `(string)` – If set to true, enables use of PingID signature. Computed by Vault
        :param pulumi.Input[str] username_format: `(string)` - A format string for mapping Identity names to MFA method names. 
               Values to substitute should be placed in `{{}}`. For example, `"{{alias.name}}@example.com"`.
               If blank, the Alias's Name field will be used as-is. Currently-supported mappings:
               - alias.name: The name returned by the mount configured via the `mount_accessor` parameter
               - entity.name: The name configured for the Entity
               - alias.metadata.`<key>`: The value of the Alias's metadata parameter
               - entity.metadata.`<key>`: The value of the Entity's metadata parameter
        """
        if admin_url is not None:
            pulumi.set(__self__, "admin_url", admin_url)
        if authenticator_url is not None:
            pulumi.set(__self__, "authenticator_url", authenticator_url)
        if idp_url is not None:
            pulumi.set(__self__, "idp_url", idp_url)
        if mount_accessor is not None:
            pulumi.set(__self__, "mount_accessor", mount_accessor)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if namespace_id is not None:
            pulumi.set(__self__, "namespace_id", namespace_id)
        if org_alias is not None:
            pulumi.set(__self__, "org_alias", org_alias)
        if settings_file_base64 is not None:
            pulumi.set(__self__, "settings_file_base64", settings_file_base64)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if use_signature is not None:
            pulumi.set(__self__, "use_signature", use_signature)
        if username_format is not None:
            pulumi.set(__self__, "username_format", username_format)

    @property
    @pulumi.getter(name="adminUrl")
    def admin_url(self) -> Optional[pulumi.Input[str]]:
        """
        `(string)` – Admin URL computed by Vault
        """
        return pulumi.get(self, "admin_url")

    @admin_url.setter
    def admin_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "admin_url", value)

    @property
    @pulumi.getter(name="authenticatorUrl")
    def authenticator_url(self) -> Optional[pulumi.Input[str]]:
        """
        `(string)` – Authenticator URL computed by Vault
        """
        return pulumi.get(self, "authenticator_url")

    @authenticator_url.setter
    def authenticator_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "authenticator_url", value)

    @property
    @pulumi.getter(name="idpUrl")
    def idp_url(self) -> Optional[pulumi.Input[str]]:
        """
        `(string)` – IDP URL computed by Vault
        """
        return pulumi.get(self, "idp_url")

    @idp_url.setter
    def idp_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "idp_url", value)

    @property
    @pulumi.getter(name="mountAccessor")
    def mount_accessor(self) -> Optional[pulumi.Input[str]]:
        """
        `(string: <required>)` - The mount to tie this method to for use in automatic mappings. 
        The mapping will use the Name field of Aliases associated with this mount as the username in the mapping.
        """
        return pulumi.get(self, "mount_accessor")

    @mount_accessor.setter
    def mount_accessor(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mount_accessor", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        `(string: <required>)` – Name of the MFA method.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> Optional[pulumi.Input[str]]:
        """
        `(string)` – Namespace ID computed by Vault
        """
        return pulumi.get(self, "namespace_id")

    @namespace_id.setter
    def namespace_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace_id", value)

    @property
    @pulumi.getter(name="orgAlias")
    def org_alias(self) -> Optional[pulumi.Input[str]]:
        """
        `(string)` – Org Alias computed by Vault
        """
        return pulumi.get(self, "org_alias")

    @org_alias.setter
    def org_alias(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_alias", value)

    @property
    @pulumi.getter(name="settingsFileBase64")
    def settings_file_base64(self) -> Optional[pulumi.Input[str]]:
        """
        `(string: <required>)` - A base64-encoded third-party settings file retrieved
        from PingID's configuration page.
        """
        return pulumi.get(self, "settings_file_base64")

    @settings_file_base64.setter
    def settings_file_base64(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "settings_file_base64", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        `(string)` – Type of configuration computed by Vault
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="useSignature")
    def use_signature(self) -> Optional[pulumi.Input[bool]]:
        """
        `(string)` – If set to true, enables use of PingID signature. Computed by Vault
        """
        return pulumi.get(self, "use_signature")

    @use_signature.setter
    def use_signature(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "use_signature", value)

    @property
    @pulumi.getter(name="usernameFormat")
    def username_format(self) -> Optional[pulumi.Input[str]]:
        """
        `(string)` - A format string for mapping Identity names to MFA method names. 
        Values to substitute should be placed in `{{}}`. For example, `"{{alias.name}}@example.com"`.
        If blank, the Alias's Name field will be used as-is. Currently-supported mappings:
        - alias.name: The name returned by the mount configured via the `mount_accessor` parameter
        - entity.name: The name configured for the Entity
        - alias.metadata.`<key>`: The value of the Alias's metadata parameter
        - entity.metadata.`<key>`: The value of the Entity's metadata parameter
        """
        return pulumi.get(self, "username_format")

    @username_format.setter
    def username_format(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username_format", value)


class MfaPingid(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 mount_accessor: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 settings_file_base64: Optional[pulumi.Input[str]] = None,
                 username_format: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a resource to manage [PingID MFA](https://www.vaultproject.io/docs/enterprise/mfa/mfa-pingid).

        **Note** this feature is available only with Vault Enterprise.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        config = pulumi.Config()
        settings_file = config.require_object("settingsFile")
        userpass = vault.AuthBackend("userpass",
            type="userpass",
            path="userpass")
        my_pingid = vault.MfaPingid("myPingid",
            mount_accessor=userpass.accessor,
            username_format="user@example.com",
            settings_file_base64=settings_file)
        ```

        ## Import

        Mounts can be imported using the `path`, e.g.

        ```sh
         $ pulumi import vault:index/mfaPingid:MfaPingid my_pingid my_pingid
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] mount_accessor: `(string: <required>)` - The mount to tie this method to for use in automatic mappings. 
               The mapping will use the Name field of Aliases associated with this mount as the username in the mapping.
        :param pulumi.Input[str] name: `(string: <required>)` – Name of the MFA method.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] settings_file_base64: `(string: <required>)` - A base64-encoded third-party settings file retrieved
               from PingID's configuration page.
        :param pulumi.Input[str] username_format: `(string)` - A format string for mapping Identity names to MFA method names. 
               Values to substitute should be placed in `{{}}`. For example, `"{{alias.name}}@example.com"`.
               If blank, the Alias's Name field will be used as-is. Currently-supported mappings:
               - alias.name: The name returned by the mount configured via the `mount_accessor` parameter
               - entity.name: The name configured for the Entity
               - alias.metadata.`<key>`: The value of the Alias's metadata parameter
               - entity.metadata.`<key>`: The value of the Entity's metadata parameter
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MfaPingidArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource to manage [PingID MFA](https://www.vaultproject.io/docs/enterprise/mfa/mfa-pingid).

        **Note** this feature is available only with Vault Enterprise.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        config = pulumi.Config()
        settings_file = config.require_object("settingsFile")
        userpass = vault.AuthBackend("userpass",
            type="userpass",
            path="userpass")
        my_pingid = vault.MfaPingid("myPingid",
            mount_accessor=userpass.accessor,
            username_format="user@example.com",
            settings_file_base64=settings_file)
        ```

        ## Import

        Mounts can be imported using the `path`, e.g.

        ```sh
         $ pulumi import vault:index/mfaPingid:MfaPingid my_pingid my_pingid
        ```

        :param str resource_name: The name of the resource.
        :param MfaPingidArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MfaPingidArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 mount_accessor: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 settings_file_base64: Optional[pulumi.Input[str]] = None,
                 username_format: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MfaPingidArgs.__new__(MfaPingidArgs)

            if mount_accessor is None and not opts.urn:
                raise TypeError("Missing required property 'mount_accessor'")
            __props__.__dict__["mount_accessor"] = mount_accessor
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            if settings_file_base64 is None and not opts.urn:
                raise TypeError("Missing required property 'settings_file_base64'")
            __props__.__dict__["settings_file_base64"] = settings_file_base64
            __props__.__dict__["username_format"] = username_format
            __props__.__dict__["admin_url"] = None
            __props__.__dict__["authenticator_url"] = None
            __props__.__dict__["idp_url"] = None
            __props__.__dict__["namespace_id"] = None
            __props__.__dict__["org_alias"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["use_signature"] = None
        super(MfaPingid, __self__).__init__(
            'vault:index/mfaPingid:MfaPingid',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            admin_url: Optional[pulumi.Input[str]] = None,
            authenticator_url: Optional[pulumi.Input[str]] = None,
            idp_url: Optional[pulumi.Input[str]] = None,
            mount_accessor: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            namespace_id: Optional[pulumi.Input[str]] = None,
            org_alias: Optional[pulumi.Input[str]] = None,
            settings_file_base64: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None,
            use_signature: Optional[pulumi.Input[bool]] = None,
            username_format: Optional[pulumi.Input[str]] = None) -> 'MfaPingid':
        """
        Get an existing MfaPingid resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] admin_url: `(string)` – Admin URL computed by Vault
        :param pulumi.Input[str] authenticator_url: `(string)` – Authenticator URL computed by Vault
        :param pulumi.Input[str] idp_url: `(string)` – IDP URL computed by Vault
        :param pulumi.Input[str] mount_accessor: `(string: <required>)` - The mount to tie this method to for use in automatic mappings. 
               The mapping will use the Name field of Aliases associated with this mount as the username in the mapping.
        :param pulumi.Input[str] name: `(string: <required>)` – Name of the MFA method.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[str] namespace_id: `(string)` – Namespace ID computed by Vault
        :param pulumi.Input[str] org_alias: `(string)` – Org Alias computed by Vault
        :param pulumi.Input[str] settings_file_base64: `(string: <required>)` - A base64-encoded third-party settings file retrieved
               from PingID's configuration page.
        :param pulumi.Input[str] type: `(string)` – Type of configuration computed by Vault
        :param pulumi.Input[bool] use_signature: `(string)` – If set to true, enables use of PingID signature. Computed by Vault
        :param pulumi.Input[str] username_format: `(string)` - A format string for mapping Identity names to MFA method names. 
               Values to substitute should be placed in `{{}}`. For example, `"{{alias.name}}@example.com"`.
               If blank, the Alias's Name field will be used as-is. Currently-supported mappings:
               - alias.name: The name returned by the mount configured via the `mount_accessor` parameter
               - entity.name: The name configured for the Entity
               - alias.metadata.`<key>`: The value of the Alias's metadata parameter
               - entity.metadata.`<key>`: The value of the Entity's metadata parameter
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MfaPingidState.__new__(_MfaPingidState)

        __props__.__dict__["admin_url"] = admin_url
        __props__.__dict__["authenticator_url"] = authenticator_url
        __props__.__dict__["idp_url"] = idp_url
        __props__.__dict__["mount_accessor"] = mount_accessor
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["namespace_id"] = namespace_id
        __props__.__dict__["org_alias"] = org_alias
        __props__.__dict__["settings_file_base64"] = settings_file_base64
        __props__.__dict__["type"] = type
        __props__.__dict__["use_signature"] = use_signature
        __props__.__dict__["username_format"] = username_format
        return MfaPingid(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="adminUrl")
    def admin_url(self) -> pulumi.Output[str]:
        """
        `(string)` – Admin URL computed by Vault
        """
        return pulumi.get(self, "admin_url")

    @property
    @pulumi.getter(name="authenticatorUrl")
    def authenticator_url(self) -> pulumi.Output[str]:
        """
        `(string)` – Authenticator URL computed by Vault
        """
        return pulumi.get(self, "authenticator_url")

    @property
    @pulumi.getter(name="idpUrl")
    def idp_url(self) -> pulumi.Output[str]:
        """
        `(string)` – IDP URL computed by Vault
        """
        return pulumi.get(self, "idp_url")

    @property
    @pulumi.getter(name="mountAccessor")
    def mount_accessor(self) -> pulumi.Output[str]:
        """
        `(string: <required>)` - The mount to tie this method to for use in automatic mappings. 
        The mapping will use the Name field of Aliases associated with this mount as the username in the mapping.
        """
        return pulumi.get(self, "mount_accessor")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        `(string: <required>)` – Name of the MFA method.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> pulumi.Output[str]:
        """
        `(string)` – Namespace ID computed by Vault
        """
        return pulumi.get(self, "namespace_id")

    @property
    @pulumi.getter(name="orgAlias")
    def org_alias(self) -> pulumi.Output[str]:
        """
        `(string)` – Org Alias computed by Vault
        """
        return pulumi.get(self, "org_alias")

    @property
    @pulumi.getter(name="settingsFileBase64")
    def settings_file_base64(self) -> pulumi.Output[str]:
        """
        `(string: <required>)` - A base64-encoded third-party settings file retrieved
        from PingID's configuration page.
        """
        return pulumi.get(self, "settings_file_base64")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        `(string)` – Type of configuration computed by Vault
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="useSignature")
    def use_signature(self) -> pulumi.Output[bool]:
        """
        `(string)` – If set to true, enables use of PingID signature. Computed by Vault
        """
        return pulumi.get(self, "use_signature")

    @property
    @pulumi.getter(name="usernameFormat")
    def username_format(self) -> pulumi.Output[Optional[str]]:
        """
        `(string)` - A format string for mapping Identity names to MFA method names. 
        Values to substitute should be placed in `{{}}`. For example, `"{{alias.name}}@example.com"`.
        If blank, the Alias's Name field will be used as-is. Currently-supported mappings:
        - alias.name: The name returned by the mount configured via the `mount_accessor` parameter
        - entity.name: The name configured for the Entity
        - alias.metadata.`<key>`: The value of the Alias's metadata parameter
        - entity.metadata.`<key>`: The value of the Entity's metadata parameter
        """
        return pulumi.get(self, "username_format")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['OidcClientArgs', 'OidcClient']

@pulumi.input_type
class OidcClientArgs:
    def __init__(__self__, *,
                 access_token_ttl: Optional[pulumi.Input[int]] = None,
                 assignments: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_type: Optional[pulumi.Input[str]] = None,
                 id_token_ttl: Optional[pulumi.Input[int]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 redirect_uris: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a OidcClient resource.
        :param pulumi.Input[int] access_token_ttl: The time-to-live for access tokens obtained by the client.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] assignments: A list of assignment resources associated with the client.
        :param pulumi.Input[str] client_type: The client type based on its ability to maintain confidentiality of credentials.
               The following client types are supported: `confidential`, `public`. Defaults to `confidential`.
        :param pulumi.Input[int] id_token_ttl: The time-to-live for ID tokens obtained by the client. 
               The value should be less than the `verification_ttl` on the key.
        :param pulumi.Input[str] key: A reference to a named key resource in Vault.
               This cannot be modified after creation. If not provided, the `default`
               key is used.
        :param pulumi.Input[str] name: The name of the client.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] redirect_uris: Redirection URI values used by the client. 
               One of these values must exactly match the `redirect_uri` parameter value
               used in each authentication request.
        """
        if access_token_ttl is not None:
            pulumi.set(__self__, "access_token_ttl", access_token_ttl)
        if assignments is not None:
            pulumi.set(__self__, "assignments", assignments)
        if client_type is not None:
            pulumi.set(__self__, "client_type", client_type)
        if id_token_ttl is not None:
            pulumi.set(__self__, "id_token_ttl", id_token_ttl)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if redirect_uris is not None:
            pulumi.set(__self__, "redirect_uris", redirect_uris)

    @property
    @pulumi.getter(name="accessTokenTtl")
    def access_token_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The time-to-live for access tokens obtained by the client.
        """
        return pulumi.get(self, "access_token_ttl")

    @access_token_ttl.setter
    def access_token_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "access_token_ttl", value)

    @property
    @pulumi.getter
    def assignments(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of assignment resources associated with the client.
        """
        return pulumi.get(self, "assignments")

    @assignments.setter
    def assignments(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "assignments", value)

    @property
    @pulumi.getter(name="clientType")
    def client_type(self) -> Optional[pulumi.Input[str]]:
        """
        The client type based on its ability to maintain confidentiality of credentials.
        The following client types are supported: `confidential`, `public`. Defaults to `confidential`.
        """
        return pulumi.get(self, "client_type")

    @client_type.setter
    def client_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_type", value)

    @property
    @pulumi.getter(name="idTokenTtl")
    def id_token_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The time-to-live for ID tokens obtained by the client. 
        The value should be less than the `verification_ttl` on the key.
        """
        return pulumi.get(self, "id_token_ttl")

    @id_token_ttl.setter
    def id_token_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "id_token_ttl", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        A reference to a named key resource in Vault.
        This cannot be modified after creation. If not provided, the `default`
        key is used.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the client.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="redirectUris")
    def redirect_uris(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Redirection URI values used by the client. 
        One of these values must exactly match the `redirect_uri` parameter value
        used in each authentication request.
        """
        return pulumi.get(self, "redirect_uris")

    @redirect_uris.setter
    def redirect_uris(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "redirect_uris", value)


@pulumi.input_type
class _OidcClientState:
    def __init__(__self__, *,
                 access_token_ttl: Optional[pulumi.Input[int]] = None,
                 assignments: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 client_type: Optional[pulumi.Input[str]] = None,
                 id_token_ttl: Optional[pulumi.Input[int]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 redirect_uris: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering OidcClient resources.
        :param pulumi.Input[int] access_token_ttl: The time-to-live for access tokens obtained by the client.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] assignments: A list of assignment resources associated with the client.
        :param pulumi.Input[str] client_id: The Client ID from Vault.
        :param pulumi.Input[str] client_secret: The Client Secret from Vault.
        :param pulumi.Input[str] client_type: The client type based on its ability to maintain confidentiality of credentials.
               The following client types are supported: `confidential`, `public`. Defaults to `confidential`.
        :param pulumi.Input[int] id_token_ttl: The time-to-live for ID tokens obtained by the client. 
               The value should be less than the `verification_ttl` on the key.
        :param pulumi.Input[str] key: A reference to a named key resource in Vault.
               This cannot be modified after creation. If not provided, the `default`
               key is used.
        :param pulumi.Input[str] name: The name of the client.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] redirect_uris: Redirection URI values used by the client. 
               One of these values must exactly match the `redirect_uri` parameter value
               used in each authentication request.
        """
        if access_token_ttl is not None:
            pulumi.set(__self__, "access_token_ttl", access_token_ttl)
        if assignments is not None:
            pulumi.set(__self__, "assignments", assignments)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if client_type is not None:
            pulumi.set(__self__, "client_type", client_type)
        if id_token_ttl is not None:
            pulumi.set(__self__, "id_token_ttl", id_token_ttl)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if redirect_uris is not None:
            pulumi.set(__self__, "redirect_uris", redirect_uris)

    @property
    @pulumi.getter(name="accessTokenTtl")
    def access_token_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The time-to-live for access tokens obtained by the client.
        """
        return pulumi.get(self, "access_token_ttl")

    @access_token_ttl.setter
    def access_token_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "access_token_ttl", value)

    @property
    @pulumi.getter
    def assignments(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of assignment resources associated with the client.
        """
        return pulumi.get(self, "assignments")

    @assignments.setter
    def assignments(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "assignments", value)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Client ID from Vault.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[str]]:
        """
        The Client Secret from Vault.
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter(name="clientType")
    def client_type(self) -> Optional[pulumi.Input[str]]:
        """
        The client type based on its ability to maintain confidentiality of credentials.
        The following client types are supported: `confidential`, `public`. Defaults to `confidential`.
        """
        return pulumi.get(self, "client_type")

    @client_type.setter
    def client_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_type", value)

    @property
    @pulumi.getter(name="idTokenTtl")
    def id_token_ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The time-to-live for ID tokens obtained by the client. 
        The value should be less than the `verification_ttl` on the key.
        """
        return pulumi.get(self, "id_token_ttl")

    @id_token_ttl.setter
    def id_token_ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "id_token_ttl", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        A reference to a named key resource in Vault.
        This cannot be modified after creation. If not provided, the `default`
        key is used.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the client.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="redirectUris")
    def redirect_uris(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Redirection URI values used by the client. 
        One of these values must exactly match the `redirect_uri` parameter value
        used in each authentication request.
        """
        return pulumi.get(self, "redirect_uris")

    @redirect_uris.setter
    def redirect_uris(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "redirect_uris", value)


class OidcClient(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token_ttl: Optional[pulumi.Input[int]] = None,
                 assignments: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_type: Optional[pulumi.Input[str]] = None,
                 id_token_ttl: Optional[pulumi.Input[int]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 redirect_uris: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Manages OIDC Clients in a Vault server. See the [Vault documentation](https://www.vaultproject.io/api-docs/secret/identity/oidc-provider#create-or-update-an-assignment)
        for more information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        test_oidc_assignment = vault.identity.OidcAssignment("testOidcAssignment",
            entity_ids=["ascbascas-2231a-sdfaa"],
            group_ids=["sajkdsad-32414-sfsada"])
        test_oidc_client = vault.identity.OidcClient("testOidcClient",
            redirect_uris=[
                "http://127.0.0.1:9200/v1/auth-methods/oidc:authenticate:callback",
                "http://127.0.0.1:8251/callback",
                "http://127.0.0.1:8080/callback",
            ],
            assignments=[test_oidc_assignment.name],
            id_token_ttl=2400,
            access_token_ttl=7200)
        ```

        ## Import

        OIDC Clients can be imported using the `name`, e.g.

        ```sh
         $ pulumi import vault:identity/oidcClient:OidcClient test my-app
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] access_token_ttl: The time-to-live for access tokens obtained by the client.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] assignments: A list of assignment resources associated with the client.
        :param pulumi.Input[str] client_type: The client type based on its ability to maintain confidentiality of credentials.
               The following client types are supported: `confidential`, `public`. Defaults to `confidential`.
        :param pulumi.Input[int] id_token_ttl: The time-to-live for ID tokens obtained by the client. 
               The value should be less than the `verification_ttl` on the key.
        :param pulumi.Input[str] key: A reference to a named key resource in Vault.
               This cannot be modified after creation. If not provided, the `default`
               key is used.
        :param pulumi.Input[str] name: The name of the client.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] redirect_uris: Redirection URI values used by the client. 
               One of these values must exactly match the `redirect_uri` parameter value
               used in each authentication request.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[OidcClientArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages OIDC Clients in a Vault server. See the [Vault documentation](https://www.vaultproject.io/api-docs/secret/identity/oidc-provider#create-or-update-an-assignment)
        for more information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vault as vault

        test_oidc_assignment = vault.identity.OidcAssignment("testOidcAssignment",
            entity_ids=["ascbascas-2231a-sdfaa"],
            group_ids=["sajkdsad-32414-sfsada"])
        test_oidc_client = vault.identity.OidcClient("testOidcClient",
            redirect_uris=[
                "http://127.0.0.1:9200/v1/auth-methods/oidc:authenticate:callback",
                "http://127.0.0.1:8251/callback",
                "http://127.0.0.1:8080/callback",
            ],
            assignments=[test_oidc_assignment.name],
            id_token_ttl=2400,
            access_token_ttl=7200)
        ```

        ## Import

        OIDC Clients can be imported using the `name`, e.g.

        ```sh
         $ pulumi import vault:identity/oidcClient:OidcClient test my-app
        ```

        :param str resource_name: The name of the resource.
        :param OidcClientArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OidcClientArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_token_ttl: Optional[pulumi.Input[int]] = None,
                 assignments: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_type: Optional[pulumi.Input[str]] = None,
                 id_token_ttl: Optional[pulumi.Input[int]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 redirect_uris: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OidcClientArgs.__new__(OidcClientArgs)

            __props__.__dict__["access_token_ttl"] = access_token_ttl
            __props__.__dict__["assignments"] = assignments
            __props__.__dict__["client_type"] = client_type
            __props__.__dict__["id_token_ttl"] = id_token_ttl
            __props__.__dict__["key"] = key
            __props__.__dict__["name"] = name
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["redirect_uris"] = redirect_uris
            __props__.__dict__["client_id"] = None
            __props__.__dict__["client_secret"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["clientSecret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(OidcClient, __self__).__init__(
            'vault:identity/oidcClient:OidcClient',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_token_ttl: Optional[pulumi.Input[int]] = None,
            assignments: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            client_id: Optional[pulumi.Input[str]] = None,
            client_secret: Optional[pulumi.Input[str]] = None,
            client_type: Optional[pulumi.Input[str]] = None,
            id_token_ttl: Optional[pulumi.Input[int]] = None,
            key: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            redirect_uris: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'OidcClient':
        """
        Get an existing OidcClient resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] access_token_ttl: The time-to-live for access tokens obtained by the client.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] assignments: A list of assignment resources associated with the client.
        :param pulumi.Input[str] client_id: The Client ID from Vault.
        :param pulumi.Input[str] client_secret: The Client Secret from Vault.
        :param pulumi.Input[str] client_type: The client type based on its ability to maintain confidentiality of credentials.
               The following client types are supported: `confidential`, `public`. Defaults to `confidential`.
        :param pulumi.Input[int] id_token_ttl: The time-to-live for ID tokens obtained by the client. 
               The value should be less than the `verification_ttl` on the key.
        :param pulumi.Input[str] key: A reference to a named key resource in Vault.
               This cannot be modified after creation. If not provided, the `default`
               key is used.
        :param pulumi.Input[str] name: The name of the client.
        :param pulumi.Input[str] namespace: The namespace to provision the resource in.
               The value should not contain leading or trailing forward slashes.
               The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
               *Available only for Vault Enterprise*.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] redirect_uris: Redirection URI values used by the client. 
               One of these values must exactly match the `redirect_uri` parameter value
               used in each authentication request.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OidcClientState.__new__(_OidcClientState)

        __props__.__dict__["access_token_ttl"] = access_token_ttl
        __props__.__dict__["assignments"] = assignments
        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["client_secret"] = client_secret
        __props__.__dict__["client_type"] = client_type
        __props__.__dict__["id_token_ttl"] = id_token_ttl
        __props__.__dict__["key"] = key
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["redirect_uris"] = redirect_uris
        return OidcClient(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessTokenTtl")
    def access_token_ttl(self) -> pulumi.Output[int]:
        """
        The time-to-live for access tokens obtained by the client.
        """
        return pulumi.get(self, "access_token_ttl")

    @property
    @pulumi.getter
    def assignments(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of assignment resources associated with the client.
        """
        return pulumi.get(self, "assignments")

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[str]:
        """
        The Client ID from Vault.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> pulumi.Output[str]:
        """
        The Client Secret from Vault.
        """
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter(name="clientType")
    def client_type(self) -> pulumi.Output[str]:
        """
        The client type based on its ability to maintain confidentiality of credentials.
        The following client types are supported: `confidential`, `public`. Defaults to `confidential`.
        """
        return pulumi.get(self, "client_type")

    @property
    @pulumi.getter(name="idTokenTtl")
    def id_token_ttl(self) -> pulumi.Output[int]:
        """
        The time-to-live for ID tokens obtained by the client. 
        The value should be less than the `verification_ttl` on the key.
        """
        return pulumi.get(self, "id_token_ttl")

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[str]:
        """
        A reference to a named key resource in Vault.
        This cannot be modified after creation. If not provided, the `default`
        key is used.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the client.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The namespace to provision the resource in.
        The value should not contain leading or trailing forward slashes.
        The `namespace` is always relative to the provider's configured [namespace](https://www.terraform.io/docs/providers/vault#namespace).
        *Available only for Vault Enterprise*.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="redirectUris")
    def redirect_uris(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Redirection URI values used by the client. 
        One of these values must exactly match the `redirect_uri` parameter value
        used in each authentication request.
        """
        return pulumi.get(self, "redirect_uris")

